@@ -111,7 +111,7 @@ def filter_default(value, default_value=u'', boolean=False):
 filter_d = filter_default
 
 
-@event('manager.startup')
+@event('manager.before_config_validate')
 def make_environment(manager):
     """Create our environment and add our custom filters"""
     global environment
@@ -195,17 +195,6 @@ def render_from_entry(template_string, entry):
             log.debug('Error during rendering: %s' % error)
             raise error
 
-    # Only try string replacement if jinja didn't do anything
-    if result == template_string:
-        try:
-            result = template_string % entry
-        except KeyError as e:
-            raise RenderError('Does not contain the field `%s` for string replacement.' % e)
-        except ValueError as e:
-            raise RenderError('Invalid string replacement template: %s (%s)' % (template_string, e))
-        except TypeError as e:
-            raise RenderError('Error during string replacement: %s' % e.message)
-
     return result
 
 
